.Dd June 28, 2006
.Dt lcg-vo-env 1
.Os 
.Bl -tag -width Ds
.Sh NAME
.Nm lcg-vo-env
.Nd define VO specific environment variables
.Sh SYNOPSIS
.Nm lcg-vo-env
.Op Fl c Li | Fl s
.Op Fl v
.Ar voname 
.Op prefix
.Sh DESCRIPTION
.Nm
is a program to generate the environment variables definitions 
needed for locating VO specific resources.
The idea is that
.Nm
is evaluated in-line by the wrapper script that is submitted to the
compute resource. It will set the relevant environment variables 
defined for the specified VO, within a namespace defined by the
user.
.Pp
The options are as follows:
.It Fl c
Generate C-shell commands on
.Dv stdout .
This is the default if
.Ev SHELL
looks like it's a csh style of shell.
.It Fl s
Generate Bourne shell commands on
.Dv stdout .
This is the default if
.Ev SHELL
does not look like it's a csh style of shell.
.It Fl v
Provide verbose and commented output. In this case, the generated commands
can not be evaluated in-line, but must be written to a file first and 
sourced later.
.Sh ""
The 
.Nm
command takes two arguments: the name of the VO in it's external representation,
i.e., as specified in an AccessControlBase rule.

If the prefix is omitted, the capitalised string of the first
name component (before the first "." in the vo name) will be used, with
any dashes ("-") replaced by underscores ("_").
.El
.Sh CONFIGURATION
The shell variables definitions are read from both a per-VO
drop-in configuration file in 
.Dv /opt/lcg/etc/lcg-vo-env.d , 
and in a common configuration file
.Dv /opt/lcg/lcg-vo-env.conf 
for all VOs. If a VO name is present in both the drop-in directory
as well as in the central config file, the central config file takes
precedence for those variables that are also defined there. Both files
consistent of colon-separated fields on rows (one per line) that cannot
be line-continued. Lines starting with a hash-sign (#) are ignored.
.Bl -tag -width Ds
.It Pa /opt/lcg/etc/lcg-vo-env.d/ voname 
Contains definitions, one per line, of the form "<postfix>:<value>".
.It Pa /opt/lcg/etc/lcg-vo-env.conf
Contains definitions, one per line, of the form "VO:<voname>:<postfix>:<value>".
.El

In case the <value> for a variable is the empty string, the variable is
unset (using the abovementioned precedence rules, such that an empty
definition in the lcg-vo-env.conf file overrides any definition set in
the drop-in configuration file.
.Sh EXAMPLES
For /opt/lcg/etc/lcg-vo-env.d/example.org:

.nf
.ft 3
.in +0.3i
  SW_DIR:/data/esia/example.org/software
  DEFAULT_SE:tbn18.nikhef.nl
.fi
.in -0.3i
.ft R

and for the central configuration file /opt/lcg/etc/lcg-vo-env.conf:

.nf
.ft 3
.in +0.3i
  VO:example.org:DEFAULT_SE:
  # this is a comment
  VO:pvier.vl-e.nl:SW_DIR:/usr/local/vosw/p4
.fi
.in -0.3i
.ft R

where the last definition of DEFAULT_SE causes this variable to be unset
for the example.org VO, overriding the entry in the file in the 
lcg-vo-env.d/ directory.

Subsequent use of the command for the example.org VO, for example in the
job submission script of in the generated job wrapper:

.nf
.ft 3
.in +0.3i
  $ eval `lcg-vo-env example.org MYVO`
  $ printenv | grep MYVO
  VO_MYVO_SW_DIR=/data/esia/example.org/software
  $ eval `lcg-vo-env pvier.vl-e.nl`
  $ printenv | grep SW_DIR
  VO_MYVO_SW_DIR=/data/esia/example.org/software
  VO_PVIER_SW_DIR=/usr/local/vosw/p4
  $
.fi
.in -0.3i
.ft R

.Sh FILES
.Bl -tag -width Ds
.It Pa /etc/sysconfig/lcg-vo-env
Contains alternate locations for the configuration files and VO definitions.
.It Pa /opt/lcg/etc/lcg-vo-env.d/ voname
Contains environment variable definitions for the VO "voname".
.It Pa /opt/lcg/etc/lcg-vo-env.conf
Contains environment variable definitions for VOs in a single common file (depricated).
.El
.Sh AUTHORS
David Groep, NIKHEF.
.Sh SEE ALSO
.Xr lcg-vo-env.conf 5 ,
.Xr lcg-vo-env.d 5
